==> haskell-irc-core-2.12-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-ICiefQh1aqU7qjv4vRVFYG
key:                  irc-core-2.12-ICiefQh1aqU7qjv4vRVFYG
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  9ba17f30152bfd13cd7e37e79178d974
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-ICiefQh1aqU7qjv4vRVFYG
depends:
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    base64-bytestring-1.2.1.0-4q5KLdrxF6BHAwlK9Y3XXj
    bytestring-0.11.5.3 hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    primitive-0.8.0.0-CgxKCR9ULfZ73CnNdOTvCD text-2.0.2 time-1.12.2
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-irc-core-2.12-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-irc-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.12
visibility:           public
id:                   irc-core-2.12-AkCFxR4pSviI0AkqEs9HzB
key:                  irc-core-2.12-AkCFxR4pSviI0AkqEs9HzB
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  4a3c1dcac3a530b719a11982bc46b7f5
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/irc-core-2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.12-AkCFxR4pSviI0AkqEs9HzB
depends:
    attoparsec-0.14.4-4lxImiie977LVZ07Q4RuOa base-4.17.2.1
    base64-bytestring-1.2.1.0-Ho7haZ0JPmRAFS27fbQFVQ
    bytestring-0.11.5.3 hashable-1.4.4.0-G3df7eBPFu1LRujEcYqf5c
    primitive-0.8.0.0-GOwpVXsLqFV9QZOjtUgUYN text-2.0.2 time-1.12.2
    vector-0.13.1.0-KSX0XQMPS0MKwOGi5hYJAY

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
